pub struct ConstValueHash(pub ConstValue);Expand description
Wrapper for ConstValue that implements Eq and Hash.
Floats don’t implement Eq/Hash due to IEEE 754 NaN semantics (NaN != NaN). This wrapper uses bitwise comparison: two floats are equal if their bit patterns match. This means:
- NaN values with identical bit patterns are considered equal
- Different NaN representations are not equal
- This is consistent with hash consing requirements
Tuple Fields
0: ConstValueTrait Implementations
Sourceimpl Clone for ConstValueHash
impl Clone for ConstValueHash
Sourcefn clone(&self) -> ConstValueHash
fn clone(&self) -> ConstValueHash
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConstValueHash
impl Debug for ConstValueHash
Sourceimpl<'de> Deserialize<'de> for ConstValueHash
impl<'de> Deserialize<'de> for ConstValueHash
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ConstValueHash
impl Hash for ConstValueHash
Sourceimpl PartialEq for ConstValueHash
impl PartialEq for ConstValueHash
Sourceimpl Serialize for ConstValueHash
impl Serialize for ConstValueHash
impl Copy for ConstValueHash
impl Eq for ConstValueHash